======================================
The Keith's Sphinx Theme Documentation
======================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   changelog
   admonitions
   lorem-ipsum
   fusce-a-nunc
   fusce-in-condimentum

.. include:: ../README.rst

Outstanding To Dos
==================

.. todo:: Define a ``toctree`` like directive to generate the list of
   blog posts with the abstract and a “read more” link (like what I have
   using SCons_)..

.. todolist::

.. _SCons: https://scons.org
